pub(super) struct AbsolutelyPositionedLineItem {
pub absolutely_positioned_box: ArcRefCell<AbsolutelyPositionedBox>,
pub preceding_line_content_would_produce_phantom_line: bool,
}Fields
absolutely_positioned_box: ArcRefCell<AbsolutelyPositionedBox>preceding_line_content_would_produce_phantom_line: boolWhether the line would be phantom if it were to end before the abspos. This is used when computing the static position (in the block axis) of an abspos whose original display had a block outer display type.