pub(super) struct TextRunLineItem {
pub text_fragment_run_data: Arc<SharedTextRunData>,
pub info: FontAndScriptInfo,
pub base_fragment_info: BaseFragmentInfo,
pub text: Vec<Arc<ShapedTextSlice>>,
pub character_range_in_dom_node: Range<Utf32CodeUnits>,
pub is_empty_for_text_cursor: bool,
}Fields
text_fragment_run_data: Arc<SharedTextRunData>info: FontAndScriptInfobase_fragment_info: BaseFragmentInfotext: Vec<Arc<ShapedTextSlice>>character_range_in_dom_node: Range<Utf32CodeUnits>The range of characters this TextRunLineItem represents within the text of its
original DOM node (modified by text transformation).
is_empty_for_text_cursor: boolWhether or not this TextFragment is an empty fragment added for the
benefit of placing a text cursor on an otherwise empty editable line.
Implementations
Sourceimpl TextRunLineItem
impl TextRunLineItem
pub(crate) fn white_space_hangs_conditionally(&self) -> bool
Sourcepub(crate) fn trim_removable_white_space_at_end(&mut self)
pub(crate) fn trim_removable_white_space_at_end(&mut self)
Trim the removable white space at the end of this TextRunLineItem.
fn trim_whitespace_at_start(&mut self, whitespace_trimmed: &mut Au) -> bool
Sourcepub(crate) fn trailing_white_space(&self) -> (TrailingWhiteSpace<Au>, bool)
pub(crate) fn trailing_white_space(&self) -> (TrailingWhiteSpace<Au>, bool)
Returns a TrailingWhiteSpace with the measurement of hanging
and removable white space and boolean saying whether or not there
was preceding content.